===========
The Library
===========

Computer games
==============

* |computer-space-games| :doc:`Computer Space Games <computer-games/computer-space-games/index>`

* |computer-battle-games| :doc:`Computer Battle Games <computer-games/computer-battle-games/index>`

* |computer-spy-games| :doc:`Computer Spy Games <computer-games/computer-spy-games/index>`

* |weird-computer-games| :doc:`Weird Computer Games <computer-games/weird-computer-games/index>`

* |creepy-computer-games| :doc:`Creepy Computer Games <computer-games/creepy-computer-games/index>`

.. |computer-space-games| image:: computer-games/computer-space-games/cover.jpg
.. |computer-battle-games| image:: computer-games/computer-battle-games/cover.jpg
.. |computer-spy-games| image:: computer-games/computer-spy-games/cover.jpg
.. |weird-computer-games| image:: computer-games/weird-computer-games/cover.jpg
.. |creepy-computer-games| image:: computer-games/creepy-computer-games/cover.jpg

Adventure games
===============

* |silver-mountain| :doc:`The Mystery of Silver Mountain <adventure-games/silver-mountain/index>`

* |island-of-secrets| :doc:`Island of Secrets <adventure-games/island-of-secrets/index>`

* |fantasy-games| :doc:`Write your own Fantasy Games <adventure-games/fantasy-games/index>`

* |adventure-programs| :doc:`Write your own Adventure Programs <adventure-games/adventure-programs/index>`

.. |silver-mountain| image:: adventure-games/silver-mountain/cover.jpg
.. |island-of-secrets| image:: adventure-games/island-of-secrets/cover.jpg
.. |fantasy-games| image:: adventure-games/fantasy-games/cover.jpg
.. |adventure-programs| image:: adventure-games/adventure-programs/cover.jpg

Introduction to Programming
===========================

* |programming-tricks-and-skills| :doc:`Programming Tricks and Skills <introduction-to-programming/programming-tricks-and-skills/index>`

* |machine-code-for-beginners| :doc:`Machine Code for Beginners <introduction-to-programming/machine-code-for-beginners/index>`

* |computer-programming-for-beginners| :doc:`Computer Programming for Beginners <introduction-to-programming/computer-programming-for-beginners/index>`

* |practical-things-microcomputer| :doc:`Practical Things to do with a Microcomputer <introduction-to-programming/practical-things-microcomputer/index>`

.. |programming-tricks-and-skills| image:: introduction-to-programming/programming-tricks-and-skills/cover.jpg
.. |machine-code-for-beginners| image:: introduction-to-programming/machine-code-for-beginners/cover.jpg
.. |computer-programming-for-beginners| image:: introduction-to-programming/computer-programming-for-beginners/cover.jpg
.. |practical-things-microcomputer| image:: introduction-to-programming/practical-things-microcomputer/cover.jpg

First computer library
======================

* |computer-fun| :doc:`Computer Fun <first-computer-library/computer-fun/index>`

* |simple-basic| :doc:`Simple Basic <first-computer-library/simple-basic/index>`

.. |computer-fun| image:: first-computer-library/computer-fun/cover.jpg
.. |simple-basic| image:: first-computer-library/simple-basic/cover.jpg

.. toctree::
   :maxdepth: 2
   :hidden:
   :glob:

   computer-games/*/index
   adventure-games/*/index
   introduction-to-programming/*/index
   first-computer-library/*/index
